@@ -19,6 +19,7 @@ from typing import cast
 from typing import Any
 
 import aiofiles
+import dsnparse
 from ckms.types import CipherText
 from ckms.types import HMACOperation
 from cryptography.exceptions import InvalidSignature
@@ -72,6 +73,14 @@ class LocalProvider(Provider):
             result = await result
         return result
 
+
+    def parse_dsn(self, dsn: dsnparse.ParseResult) -> KeySpecification:
+        return {
+            **dsn.query, # type: ignore
+            'provider': 'local',
+            'key': {'path': dsn.path[1:]} # type: ignore
+        }
+
     @functools.singledispatchmethod
     def _generate(self, spec: Any) -> Any:
         raise NotImplementedError(repr(spec))
