@@ -15,6 +15,7 @@
 from typing import Any
 from typing import Generator
 
+import dsnparse
 import pydantic
 
 from ckms.core import const
@@ -41,7 +42,7 @@ class KeySpecification(BaseKeySpecification, Decrypter, Encrypter, Signer, Verif
     kty: str
     kid: str | None = None
     use: KeyUseType | None
-    algorithm: Algorithm
+    algorithm: Algorithm = pydantic.Field(default=None, alias='alg')
     allow: set[str] = set()
     curve: str | None = None
     loaded: bool = False
@@ -49,8 +50,13 @@ class KeySpecification(BaseKeySpecification, Decrypter, Encrypter, Signer, Verif
     key_ops: set[KeyOperationType] = set()
     certificate: Certificate | None
 
+    class Config(BaseKeySpecification.Config):
+        allow_population_by_field_name: bool = True
+
     @pydantic.root_validator(allow_reuse=True, pre=True)
     def _autodiscover(cls, values: dict[str, Any]) -> dict[str, Any]:
+        if values.get('alg'):
+            values['algorithm'] = values['alg']
         cls.autodiscover(
             values['provider'],
             values['provider'].inspector,
@@ -68,6 +74,14 @@ class KeySpecification(BaseKeySpecification, Decrypter, Encrypter, Signer, Verif
         """Hook to override key-specific validations."""
         pass
 
+    @classmethod
+    def parse_dsn(
+        cls,
+        dsn: dsnparse.ParseResult,
+        **kwargs: Any
+    ) -> dict[str, Any]:
+        raise NotImplementedError
+
     def __init__(self, **kwargs: Any):
         super().__init__(**kwargs)
         assert isinstance(self.provider, IProvider)
