@@ -29,6 +29,7 @@ from ckms.types import IKeySpecification
 from ckms.types import IProvider
 from ckms.types import Signer
 from ckms.types import Verifier
+from .certificate import Certificate
 
 
 class PublicKeySpecification(IKeySpecification, Encrypter, Verifier, pydantic.BaseModel):
@@ -42,6 +43,7 @@ class PublicKeySpecification(IKeySpecification, Encrypter, Verifier, pydantic.Ba
     key_ops: set[KeyOperationType]
     tags: set[str] = set()
     key: CryptographyPublicKeyType
+    certificate: Certificate | None
 
     @property # type: ignore
     def algorithm(self) -> str:
@@ -49,13 +51,16 @@ class PublicKeySpecification(IKeySpecification, Encrypter, Verifier, pydantic.Ba
 
     def as_jwk(self, private: bool = False) -> dict[str, Any]:
         assert not private
-        return {
+        claims: dict[str, Any] = {
             **self.provider.inspector.to_jwk(self.key),
             'alg': self.alg,
             'crv': self.crv,
             'use': self.use,
             'key_ops': self.key_ops
         }
+        if self.certificate:
+            claims.update(self.certificate.claims())
+        return claims
 
     def can_sign(self) -> bool:
         return False
